@@ -125,9 +125,9 @@ account_type_from_pwent (struct passwd *pwent)
                 return ACCOUNT_TYPE_ADMINISTRATOR;
         }
 
-        grp = getgrnam ("wheel");
+        grp = getgrnam (ADMIN_GROUP);
         if (grp == NULL) {
-                g_debug ("wheel group not found");
+                g_debug (ADMIN_GROUP " group not found");
                 return ACCOUNT_TYPE_STANDARD;
         }
         wheel = grp->gr_gid;
@@ -287,7 +287,8 @@ user_update_from_pwent (User          *user,
 
         user->system_account = daemon_local_user_is_excluded (user->daemon,
                                                               user->user_name,
-                                                              pwent->pw_shell);
+                                                              pwent->pw_shell,
+                                                              passwd);
 
         g_object_thaw_notify (G_OBJECT (user));
 
@@ -315,7 +316,7 @@ user_update_from_keyfile (User     *user,
         if (s != NULL) {
                 g_free (user->x_session);
                 user->x_session = s;
-                g_object_notify (G_OBJECT (user), "x-session");
+                g_object_notify (G_OBJECT (user), "xsession");
         }
 
         s = g_key_file_get_string (keyfile, "User", "Email", NULL);
@@ -1297,7 +1298,7 @@ user_change_account_type_authorized_cb (Daemon                *daemon,
                          "change account type of user '%s' (%d) to %d",
                          user->user_name, user->uid, account_type);
 
-                grp = getgrnam ("wheel");
+                grp = getgrnam (ADMIN_GROUP);
                 if (grp == NULL) {
                         throw_error (context, ERROR_FAILED, "failed to set account type: wheel group not found");
                         return;
